@@ -1,6 +1,3 @@
-
-context("print")
-
 test_that("short", {
   skip_if_offline()
 
@@ -9,7 +6,6 @@ test_that("short", {
   expect_equal(length(out), 12)
   expect_match(out[1], "csardi.*packages in.*seconds")
   expect_match(out[2], "#\\s+package\\s+version\\s+by\\s+@\\s+title")
-  expect_match(out[3], "100\\s+igraph.*Gábor Csárdi.*Network Analysis")
 })
 
 test_that("long", {
@@ -18,9 +14,8 @@ test_that("long", {
   x <- ps("csardi", "long")
   out <- capture.output(print(x))
   expect_match(out[1], "csardi.*packages in.*seconds")
-  expect_match(out[3], "^1 igraph")
-  expect_true(any(grepl("igraph.org", out, fixed = TRUE)))
-  expect_true(any(grepl("G.bor Cs.rdi", out)))
+  expect_true(any(grepl("github.com/r-lib/crayon", out, fixed = TRUE)))
+  expect_true(any(grepl("G.*bor Cs.*rdi", out)))
 })
 
 test_that("left_right if they do not fit", {
